rpds_py: Python bindings to Rust's persistent data structures (rpds)
====================================================================

Description
-----------

Python bindings to Rust's persistent data structures (rpds)

In SageMath, this package is used as a dependency package of the
Jupyter notebook / JupyterLab.

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/rpds-py/

